import React, { useRef, useEffect } from 'react';
import { ChevronRight } from 'lucide-react';

interface TerminalButtonProps {
  children: React.ReactNode;
  onClick?: () => void;
  isSelected?: boolean;
}

const TerminalButton: React.FC<TerminalButtonProps> = ({ children, onClick, isSelected }) => {
  const buttonRef = useRef<HTMLButtonElement>(null);
  const shineRef = useRef<HTMLDivElement>(null);
  
  // Play sound effect on button click
  const playKeyPress = () => {
    const audio = new Audio('data:audio/wav;base64,UklGRnQGAABXQVZFZm10IBAAAAABAAEARKwAAIhYAQACABAAZGF0YU8GAACBhYqFbF1fdH2Dg4R/gIKFi4SAgX98eoCFhQAAhIWKhWxdX3R9g4OEf4CChYuEgIF/fHqAhYUAAP//');
    audio.volume = 0.2;
    audio.play().catch(() => {});
  };
  
  const handleClick = (e: React.MouseEvent) => {
    playKeyPress();
    onClick?.(e);
    
    // Create ripple effect
    if (buttonRef.current) {
      const button = buttonRef.current;
      const rect = button.getBoundingClientRect();
      const x = e.clientX - rect.left;
      const y = e.clientY - rect.top;
      
      const ripple = document.createElement('div');
      ripple.className = 'absolute rounded-full bg-green-400/10';
      ripple.style.left = `${x}px`;
      ripple.style.top = `${y}px`;
      ripple.style.width = '0';
      ripple.style.height = '0';
      ripple.style.transform = 'translate(-50%, -50%)';
      button.appendChild(ripple);
      
      setTimeout(() => {
        ripple.style.width = '300px';
        ripple.style.height = '300px';
        ripple.style.opacity = '0';
        ripple.style.transition = 'all 0.8s ease-out';
      }, 0);
      
      setTimeout(() => {
        button.removeChild(ripple);
      }, 800);
    }
  };
  
  // Track mouse movement for shine effect
  const handleMouseMove = (e: MouseEvent) => {
    if (buttonRef.current && shineRef.current) {
      const button = buttonRef.current;
      const shine = shineRef.current;
      const rect = button.getBoundingClientRect();
      
      const x = (e.clientX - rect.left) / rect.width;
      const y = (e.clientY - rect.top) / rect.height;
      
      // Move shine based on cursor position
      shine.style.opacity = '0.2';
      shine.style.transform = `translate(-50%, -50%) scale(2) translate(${x * 100}%, ${y * 100}%)`;
    }
  };
  
  const handleMouseEnter = () => {
    document.addEventListener('mousemove', handleMouseMove);
  };
  
  const handleMouseLeave = () => {
    document.removeEventListener('mousemove', handleMouseMove);
    if (shineRef.current) {
      shineRef.current.style.opacity = '0';
    }
  };
  
  useEffect(() => {
    return () => {
      document.removeEventListener('mousemove', handleMouseMove);
    };
  }, []);
  
  return (
    <button 
      ref={buttonRef}
      className={`terminal-button group ${isSelected ? 'terminal-button-selected' : ''} relative overflow-hidden transition-all duration-200`}
      onClick={handleClick}
      onMouseEnter={handleMouseEnter}
      onMouseLeave={handleMouseLeave}
    >
      {/* Static subtle glare effect */}
      <div className="glare-effect"></div>
      
      {/* Dynamic shine effect that follows cursor */}
      <div 
        ref={shineRef}
        className="absolute w-40 h-40 rounded-full bg-gradient-to-r from-transparent via-green-400/10 to-transparent pointer-events-none opacity-0 transition-opacity duration-300"
        style={{ 
          top: '50%', 
          left: '50%', 
          transform: 'translate(-50%, -50%) scale(2)'
        }}
      ></div>
      
      {/* Button content with icons */}
      <div className="relative z-10 flex items-center">
        <ChevronRight 
          className={`inline-block mr-2 w-4 h-4 transition-all duration-200 
                     ${isSelected ? 'text-green-400' : 'text-green-500/80'}
                     group-hover:translate-x-1 group-hover:text-green-400`} 
        />
        <span className="transition-all duration-200">{children}</span>
      </div>
      
      {/* Scan line effect over button */}
      <div 
        className="absolute inset-0 pointer-events-none opacity-10 z-20"
        style={{
          backgroundImage: 'linear-gradient(to bottom, transparent, transparent 50%, rgba(0, 0, 0, 0.4) 50%, rgba(0, 0, 0, 0.4))',
          backgroundSize: '100% 4px'
        }}
      ></div>
    </button>
  );
}

export default TerminalButton;